package android.project.Koo;

import android.database.Cursor;
import java.io.Serializable;

/**
 * Contenitore dati per un contatto.
 * Implementa Serializable per permettere il suo utilizzo
 * all'interno degli Intent Android.
 * 
 * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
 */
public class Contact implements Serializable
{
	static final long serialVersionUID = 42L;

	private String name;
	private String phone;
	private String email;
	private String company;
	private long id;

	/**
	 * Setta il nome.
	 * 
	 * @param name Nome
	 */
	public void setName (String name)
	{
		this.name=name;
	}

	/**
	 * Restituisce il nome.
	 * 
	 * @return Nome
	 */
	public String getName()
	{
		return this.name;
	}
	
	/**
	 * Setta il numero telefonico.
	 * 
	 * @param phone Numero telefonico
	 */
	public void setPhone (String phone)
	{
		this.phone=phone;
	}

	/**
	 * Restituisce il numero telefonico.
	 * 
	 * @return Numero telefonico
	 */
	public String getPhone()
	{
		return this.phone;
	}

	/**
	 * Setta l'email.
	 * 
	 * @param email Email
	 */
	public void setEMail (String email)
	{
		this.email=email;
	}

	/**
	 * Restituisce l'email.
	 * 
	 * @return Email
	 */
	public String getEMail()
	{
		return this.email;
	}

	/**
	 * Setta il nome della compagnia.
	 * 
	 * @param company Nome della comapagnia
	 */
	public void setCompany (String company)
	{
		this.company=company;
	}

	/**
	 * Restituisce il nome della compagnia.
	 * 
	 * @return Nome della compagnia
	 */
	public String getCompany()
	{
		return this.company;
	}
	
	/**
	 * Setta l'identificatore di riga.
	 * 
	 * @param id Identificatore di riga
	 */
	public void setId (long id)
	{
		this.id=id;
	}

	/**
	 * Restituisce l'identificatore di riga.
	 * 
	 * @return Identificatore di riga
	 */
	public long getId()
	{
		return this.id;
	}
	
	/**
	 * Costruisce, a partire da una riga del DB, un nuovo contatto.
	 *  
	 * @param cursor Cursore ad una riga della tabella del contatti presente nel DB
	 * @return Un nuovo oggetto di tipo Contact
	 */
	static Contact CursorToContact(Cursor cursor)
	{
		Contact contact = new Contact();
		
		// Estraggo i dati del contatto dalle colonne rispettive colonne
    	contact.setName(cursor.getString(DBAdapter.POS_CONTACTS_NAME));
    	contact.setPhone(cursor.getString(DBAdapter.POS_CONTACTS_PHONE));
    	contact.setEMail(cursor.getString(DBAdapter.POS_CONTACTS_EMAIL));
    	contact.setCompany(cursor.getString(DBAdapter.POS_CONTACTS_COMPANY));
    	
    	return contact;
	}
}
