package android.project.Koo;

import android.app.Activity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.content.Intent;
import android.widget.EditText;

/**
 * Activity per la visualizzazione e l'editing dei contatti.
 * 
 * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
 */
public final class ContactEditActivity extends Activity
{
	/* Identificatori per le opzioni del menu' contestuale */
	public static final int OPTION_MENU_OK = Menu.FIRST;
	public static final int OPTION_MENU_CANCEL = OPTION_MENU_OK+1;
	
	/* Id del contatto in editing */
	private long contactId;
	
	/* Widgets */
	private EditText etName;
	private EditText etPhone;
	private EditText etEMail;
	private EditText etCompany;
	
    @Override
    /**
     * Metodo invocato dal sistema Android alla creazione
     * dell'Activity.
     * 
     * @param savedInstanceState Dati di istanza, utilizzabili per ripristinare
     * un precedente stato dell'Activity
     */
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        // Setto il layout dell'activity
        setContentView(R.layout.contact_view);

        // Estraggo l'azione dall'Intent
        if (getIntent().getAction().equals(Actions.EDIT_CONTACT_ACTION))
        {
        	// Estraggo l'intent dall'Intent
        	Contact contact = (Contact) getIntent().getExtras().get("contact");
        	// Salvo l'id per ripristinarlo successivamente
        	contactId = contact.getId();
        	
        	// Estraggo le reference agli widgets
        	etName = (EditText) findViewById(R.id.EditTextName);
        	etPhone = (EditText) findViewById(R.id.EditTextPhone);
        	etEMail = (EditText) findViewById(R.id.EditTextEMail);
        	etCompany = (EditText) findViewById(R.id.EditTextCompany);

        	// Valorizzo i campi da editare
        	etName.setText(contact.getName());
        	etPhone.setText(contact.getPhone());
        	etEMail.setText(contact.getEMail());
        	etCompany.setText(contact.getCompany());
        }
    }

    @Override
    /**
     * Metodo invocato dal sistema Android dopo la creazione del menu'
     * contestuale. In questa fase vanno aggiunti i bottoni opzione
     * desiderati.
     * 
     * @param menu Referenza al menu' contestuale
     * @return false in caso di errore, true altrimenti
     */
    public boolean onCreateOptionsMenu(Menu menu)
    {
        boolean result = super.onCreateOptionsMenu(menu);
        
        // Aggiungo le opzioni al menu'
        menu.add(0, OPTION_MENU_OK, 0, R.string.menu_ok);
        menu.add(0, OPTION_MENU_CANCEL, 0, R.string.menu_cancel);
        
        return result;
    }
    
    @Override
    /**
     * Metodo invocato dal sistema Android alla pressione di
     * un bottone del menu' contestuale.
     * 
     * @param menu Referenza al bottone premuto dall'utente
     * @return false in caso di errore, true altrimenti
     */
    public boolean onOptionsItemSelected(MenuItem item)
    {
    	// Controllo l'Id del bottone
        switch(item.getItemId())
        {
        	case OPTION_MENU_OK:
        		returnContact();
        		return true;
        		
        	case OPTION_MENU_CANCEL:
        		returnCancel();
        		return true;
    	}
        
        return super.onOptionsItemSelected(item);
    }
    
    /**
     * Costruisce un oggetto contact a partire dalle informazioni
     * inserite dall'utente e lo restituisce come risultato
     * all'activity chiamante.
     */
    void returnContact()
    {
    	Contact contact = new Contact();
    	
    	// Estraggo le informazioni del contatto
    	contact.setName(etName.getText().toString());
    	contact.setPhone(etPhone.getText().toString());
    	contact.setEMail(etEMail.getText().toString());
    	contact.setCompany(etCompany.getText().toString());
    	
    	// Ripristino l'Id del contatto
    	contact.setId(contactId);
    	
    	// Inserisco i dati del contatto all'interno di un Intent
    	Bundle bundle = new Bundle();
    	bundle.putSerializable("contact", contact);
    	Intent i = new Intent();
    	i.putExtras(bundle);

    	// Informo l'activity chiamante che l'editing si è concluso
    	// con successo
    	setResult(RESULT_OK, i);
    	finish();
    }

    /**
     * Annulla l'editing del contatto.
     */
    void returnCancel()
    {
    	Intent i = new Intent();
    	
    	// Informo l'activity chiamante dell'annullamento dell'editing
    	setResult(RESULT_CANCELED, i);
    	finish();
    }
}

