package android.project.Koo;

import android.app.ListActivity;
import android.net.Uri;
import android.os.Bundle;
import android.content.Intent;
import android.database.Cursor;
import android.widget.SimpleCursorAdapter;
import android.view.View;
import android.app.Dialog;
import android.widget.Button;
import android.widget.TextView;
import android.widget.AdapterView;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View.OnClickListener;

/**
 * Activity per la visualizzazione della lista contatti.
 * 
 * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
 */
public class ContactsListActivity extends ListActivity
{
	/* Identificatori per la creazione dei dialoghi contestuali */
	static final int SHOW_DIALOG_VIEW_CONTACT = 1;

	/* Identificatori per le opzioni del menu' contestuale */
	public static final int OPTION_MENU_INSERT_ID = Menu.FIRST;
	public static final int OPTION_MENU_DELETE_ID = OPTION_MENU_INSERT_ID+1;
	public static final int OPTION_MENU_EDIT_ID = OPTION_MENU_DELETE_ID+1;
	
	/* Tipi di richieste all'activity di editing */
	public static final int REQUEST_NEW_CONTACT = 0;
	public static final int REQUEST_EDIT_CONTACT = 1;

	/* Referenza al DB */
	private DBAdapter db;
	/* Contatto selezionato */
	private Contact selectedContact = null;

    @Override
    /**
     * Metodo invocato dal sistema Android alla creazione
     * dell'Activity.
     * 
     * @param savedInstanceState Dati di istanza, utilizzabili per ripristinare
     * un precedente stato dell'Activity
     */
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        
        db = new DBAdapter(this);
        // Apro il DB
        db.open();

        // Estraggo l'elenco dei contatti presente nel DB
        // e li visualizzo tramite un CursorAdapter
        Cursor cursor = db.getAllContacts();
        startManagingCursor(cursor);

        SimpleCursorAdapter adapter = new SimpleCursorAdapter(
        		this,
        		android.R.layout.simple_list_item_2,
        		cursor,
        		new String[] { DBAdapter.KEY_CONTACTS_NAME, DBAdapter.KEY_CONTACTS_EMAIL},
        		new int[] {android.R.id.text1, android.R.id.text2});
        
        setListAdapter(adapter);
        
        // Catturo e gestisco l'evento "long click"
        getListView().setOnItemLongClickListener(
        	new AdapterView.OnItemLongClickListener ()
        	{
        		//@Override
        		public boolean onItemLongClick(AdapterView<?> av, View v, int pos, long id)
        		{
        			onLongListItemClick(v, pos, id);
        			return false;
        		}
        	}
        );
    }

    @Override
    /**
     * Metodo invocato per la creazione del dialogo contestuale
     * 
     * @param id Identificatore del tipo di dialogo
     * @return Referenza all'oggetto Dialog
     */
    protected Dialog onCreateDialog(int id)
    {
    	Dialog dialog;
    	
    	switch(id)
    	{
	    	case SHOW_DIALOG_VIEW_CONTACT:
	        	dialog = new Dialog(this);     
    		break;

    		default:
    			dialog = null;
    	}

    	return dialog;
    }

    @Override
    /**
     * Metodo invocato per la creazione del dialogo contestuale.
     * 
     * @param id Identificatore del tipo di dialogo
     * @return Referenza all'oggetto Dialog
     */
    protected void onPrepareDialog(int id, Dialog dialog)
    {
    	switch (id)
    	{
    		case SHOW_DIALOG_VIEW_CONTACT:
    			prepareContactDialog(dialog);
    			break;
    	}
    }
    
    /**
     * Visualizza sul dialogo contestuale le informazioni di un contatto.
     * 
     * @param dialog Referenza all'oggetto Dialog
     */    
    private void prepareContactDialog(Dialog dialog)
    {
    	// Setto il layout dell'activity
		dialog.setContentView(R.layout.view_contact_dialog);
		
		// Titolo
		dialog.setTitle(this.selectedContact.getName() + "              ");
		
		// Compagnia
		TextView tvCompany = (TextView) dialog.findViewById(R.id.TextViewCompany);
		tvCompany.setText(this.selectedContact.getCompany());
		
		// Numero telefonico
		TextView tvPhone = (TextView) dialog.findViewById(R.id.TextViewPhone);
		tvPhone.setText(this.selectedContact.getPhone());
		
		// email
		TextView tvEMail = (TextView) dialog.findViewById(R.id.TextViewEMail);
		tvEMail.setText(this.selectedContact.getEMail());

		// Bottone di chiamata
        Button bCall = (Button) dialog.findViewById(R.id.ButtonCall);
        bCall.setOnClickListener(new OnClickListenerCall());
        
        // Bottone di invo email
        Button bSendEMail = (Button) dialog.findViewById(R.id.ButtonSendEMail);
        bSendEMail.setOnClickListener(new OnClickListenerSendEMail());
    }
    
    /**
     * Classe callback per l'evento click del bottone "Call".
     * 
     * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
     */
    class OnClickListenerCall implements OnClickListener
    {
		public void onClick(View v)
		{
			// Richiedo l'effettuazione di una chiamata al sistema Android
			Intent intent = new Intent(Intent.ACTION_CALL);
			intent.setData(Uri.parse("tel: " + selectedContact.getPhone()));
			startActivity(intent);
		}
    }

    /**
     * Classe callback per l'evento click del bottone "Send email".
     * 
     * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
     */
    class OnClickListenerSendEMail implements OnClickListener
    {
		public void onClick(View v)
		{
			// Richiedo l'invio di una email al sistema Android
			Intent intent = new Intent(Intent.ACTION_SENDTO, Uri.parse("mailto:" + selectedContact.getEMail()));
			intent.putExtra("subject", "From Koo Android Application");
			startActivity(intent);
		}
    }
    
    @Override
    /**
     * Metodo invocato dal sistema Android dopo la creazione del menu'
     * contestuale. In questa fase vanno aggiunti i bottoni opzione
     * desiderati.
     * 
     * @param menu Referenza al menu' contestuale
     * @return false in caso di errore, true altrimenti
     */
    public boolean onCreateOptionsMenu(Menu menu)
    {
        boolean result = super.onCreateOptionsMenu(menu);
        
        // Aggiungo le opzioni al menu'
        menu.add(0, OPTION_MENU_EDIT_ID, 0, R.string.menu_edit);
        menu.add(0, OPTION_MENU_DELETE_ID, 0, R.string.menu_delete);
		menu.add(0, OPTION_MENU_INSERT_ID, 0, R.string.menu_insert);

        return result;
    }
    
    @Override
    /**
     * Metodo invocato dal sistema Android alla pressione di
     * un bottone del menu' contestuale.
     * 
     * @param menu Referenza al bottone premuto dall'utente
     * @return false in caso di errore, true altrimenti
     */
    public boolean onOptionsItemSelected(MenuItem item)
    {
    	// Controllo l'Id del bottone
        switch(item.getItemId())
        {
        	case OPTION_MENU_INSERT_ID:
        		createContact();
        		return true;
        		
        	case OPTION_MENU_DELETE_ID:
        		deleteContact();
        		return true;
        		
        	case OPTION_MENU_EDIT_ID:
        		editContact();
        		return true;
    	}
        
        return super.onOptionsItemSelected(item);
    }
    
    /**
     * Elimina il contatto selezionato nella lista.
     */
    private void deleteContact()
    {
    	if (getSelectedItemId() == AdapterView.INVALID_ROW_ID)
    		return;
    	
    	db.deleteContact(getSelectedItemId());
    	fillData();
    }

    /**
     * Avvia l'activity per la creazione di un nuovo contatto
     */
    private void createContact()
    {
    	Contact contact = new Contact();
    	
    	// Creo l'Intent per l'editing di un contatto ed 
    	// aggiungo la referenza ad un oggetto contact vuoto
		Intent i = new Intent(Actions.EDIT_CONTACT_ACTION);
		i.putExtra("contact", contact);
		
		// Avvio l'activity ContactEditActivity richiedendo
		// la creazione di un nuovo contatto
		startActivityForResult(i, REQUEST_NEW_CONTACT);
    }
    
    /**
     * Avvia l'activity per l'editing del contatto selezionato
     * nella lista contatti.
     */
    private void editContact()
    {
    	if (getSelectedItemId() == AdapterView.INVALID_ROW_ID)
    		return;
    	
    	// Creo un contatto a partire dai dati contenuti nel database
    	Contact contact = Contact.CursorToContact(db.getContact(getSelectedItemId()));
    	contact.setId(getSelectedItemId());
    	
    	// Creo l'Intent per l'editing di un contatto ed 
    	// aggiungo la referenza all'oggetto Contact creato precedentemente
		Intent i = new Intent(Actions.EDIT_CONTACT_ACTION);
		i.putExtra("contact", contact);
		
		// Avvio l'activity ContactEditActivity richiedendo
		// l'editing di un contatto
		startActivityForResult(i, REQUEST_EDIT_CONTACT);
    }

    /**
     * Aggiorna la lista dei contatti.
     */
    private void fillData()
    {
    	Cursor cursor = db.getAllContacts();
    	((SimpleCursorAdapter) getListAdapter()).changeCursor(cursor);
    }
    
    //@Override
    /**
     * Metodo invocato dal sistema Android in corrispondenza
     * di un evento LongClick su un'elemento della lista dei contatti.
     */
    protected void onLongListItemClick(View v, int position, long id)
    {
    	Contact contact = Contact.CursorToContact(db.getContact(((SimpleCursorAdapter)getListAdapter()).getItemId(position)));

    	this.selectedContact = contact;
    	
    	// Lancio il dialogo per la visualizzazione dei contatti
    	showDialog(SHOW_DIALOG_VIEW_CONTACT);
    }
    
    @Override
    /**
     * Metodo invocato dal sistema Android al completamento di una activity
     * invocata con il metodo startActivityForResult.
     * 
     * @param requestCore Codice della richiesta
     * @param resultCode Risultato della richiesta
     * @param data Intent contenente i risultati
     */
    protected void onActivityResult(int requestCode, int resultCode, Intent data)
    {
    	super.onActivityResult(requestCode, resultCode, data);
    	
    	// Controllo se l'activity ha completato correttamente
    	// la richiesta
    	if (resultCode == RESULT_OK)
    	{
    		// Estraggo i dati del contatto dall'Intent 
    		Bundle extras = data.getExtras();
    		Contact contact = (Contact) extras.getSerializable("contact");

    		// Controllo il codice della richiesta
    		switch (requestCode)
    		{
    			case REQUEST_NEW_CONTACT:
    				// Inserisco il nuovo contatto all'interno del DB
    				db.insertContact(contact);
    				fillData();
    			break;
    			
    			case REQUEST_EDIT_CONTACT:
    				// Aggiorno le informazione del contatto
    				db.updateContact(contact.getId(), contact);
    				fillData();
    			break;
    		}
    	}
    }
}

