package android.project.Koo;

import java.io.Serializable;

import android.app.Activity;
import android.os.Bundle;
import android.content.Intent;
import android.view.View.OnClickListener;
import android.view.View;
import android.widget.Button;


/**
 * Activity principale.
 * 
 * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
 */
public class Koo extends Activity
{
	/* Codici di richiesta per le activity */
	public static final int REQUEST_NEW_CONTACT = 1;
	
	/* Referenza al DB */
    DBAdapter db;
	
    @Override
    /**
     * Metodo invocato dal sistema Android alla creazione
     * dell'Activity.
     * 
     * @param savedInstanceState Dati di istanza, utilizzabili per ripristinare
     * un precedente stato dell'Activity
     */
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        // Setto il layout dell'Activity
        setContentView(R.layout.main);

        // Creo il DB
        db = new DBAdapter(this);
    
        // Estraggo le referenze ai bottoni "Insert contact" e "View contacts"
        Button insertContactButton = (Button)findViewById(R.id.ButtonInsertContact);
        Button viewContactsButton = (Button)findViewById(R.id.ButtonViewContacts);
        
        // Setto le classi callback per i rispettivi eventi onClick
        viewContactsButton.setOnClickListener(new OnClickListenerViewContacts());
        insertContactButton.setOnClickListener(new OnClickListenerInsertContact());
    }
    
    /**
     * Classe callback per l'evento onClick del bottone "View contacts".
     * 
     * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
     */
    class OnClickListenerViewContacts implements OnClickListener
    {
    	/**
    	 * Metodo invocato per gestire l'evento click.
    	 * 
    	 * @param v Referenza al bottone che ha generato l'evento
    	 */
		public void onClick(View v)
		{
			// Creo un nuovo Intent per l'azione VIEW_CONTACTS_LIST_ACTION
			Intent i = new Intent(Actions.VIEW_CONTACTS_LIST_ACTION);
			
			// Avvio l'activity ContactsListActivity
			startActivity(i);
		}
    }

    /**
     * Classe callback per l'evento onClick del bottone "View contacts".
     * 
     * @author Francesco Marcantoni, Francesco Rigo, Michele Ambrosi 
     */
    class OnClickListenerInsertContact implements OnClickListener
    {
    	/**
    	 * Metodo invocato per gestire l'evento click.
    	 * 
    	 * @param v Referenza al bottone che ha generato l'evento
    	 */
    	public void onClick(View v)
		{
        	Contact contact = new Contact();
        
        	// Creo un nuovo Intent per l'azione EDIT_CONTACT_ACTION
    		Intent i = new Intent(Actions.EDIT_CONTACT_ACTION);
    		
    		// Inserisco all'interno dell'Intent l'oggetto contact creato
    		// precedentemente e assegno ad esso la key "contact"
    		i.putExtra("contact", (Serializable) contact);
    		
    		// Avvio l'activity ContactEditActivity. Diversamente dal caso
    		// precedente l'activity in questione viene invocata per ottenere
    		// un risultato, cioe' le modifiche apportate dall'utente al contatto
    		// fornito come parametro.
    		startActivityForResult(i, REQUEST_NEW_CONTACT);
		}
    }
    
    @Override
    /**
     * Metodo invocato dal sistema Android al completamento di una activity
     * invocata con il metodo startActivityForResult.
     * 
     * @param requestCore Codice della richiesta
     * @param resultCode Risultato della richiesta
     * @param data Intent contenente i risultati
     */
    protected void onActivityResult(int requestCode, int resultCode, Intent data)
    {
    	super.onActivityResult(requestCode, resultCode, data);
    	
    	// Controllo se l'activity ha completato correttamente
    	// la richiesta
    	if (resultCode == RESULT_OK)
    	{
    		// Estraggo i dati del contatto dall'Intent 
    		Bundle extras = data.getExtras();
    		Contact contact = (Contact) extras.getSerializable("contact");

    		// Controllo il codice della richiesta, in questo caso
    		// l'unico tipo di richiesta possibile e' REQUEST_NEW_CONTACT
    		switch (requestCode)
    		{
    			case REQUEST_NEW_CONTACT:
    				// Inserisco il nuovo contatto all'interno del DB
    		        db.open();
    				db.insertContact(contact);
    				db.close();
    			break;
    		}
    	}
    }
}